@@ -1,5 +1,5 @@
-/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.3.
-   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.7.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 10 Sep.2004, Siracusa (Italy), J.M.Sellier
-// Last modif. : 01 Mar.2005, Siracusa (Italy), J.M.Sellier
+// Last modif. : 27 Dec.2006, Siracusa (Italy), J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -67,7 +67,7 @@ SaveOutput2DGNUPLOT(int je)
  FILE *fL;
  register int i,j;
 
-if(Material==SILICON){
+if(Material==SILICON || Material==GERMANIUM){
  if(je<=9){
    sprintf(s,"density00%d.xyz",je);
    fp=fopen(s,"w");
